@@ -68,196 +68,229 @@
 #' @importFrom utils tail
 #' @importFrom stats sd
 #' @export
-exposure <- function(model=NULL,output=NULL, group=NULL,treatment=NULL,parameter=NULL,
-                     data=NULL, project=NULL, settings=NULL, regressor=NULL, varlevel=NULL)
-{  
-  if (!is.null(group)){
-    if (!is.null(group$output))
-      stop("\n'output' cannot be defined in 'group' with exposure\n", call.=FALSE)
+exposure <- function (model = NULL, output = NULL, group = NULL, treatment = NULL, 
+                      parameter = NULL, data = NULL, project = NULL, settings = NULL, 
+                      regressor = NULL, varlevel = NULL) 
+{
+  if (!is.null(group)) {
+    if (!is.null(group$output)) 
+      stop("\n'output' cannot be defined in 'group' with exposure\n", 
+           call. = FALSE)
   }
-  if (identical(output$time,"steady.state")){
-    
-    if (is.null(output$ntp)) {ntp<-100}  else {ntp<-output$ntp}
-    if (is.null(output$ngc)) {ngc<-5}    else {ngc<-output$ngc}
-    if (is.null(output$tol)) {tol<-0.01} else {tol<-output$tol}
-    
-    # groups and treatment
-    if (is.null(group))
+  if (identical(output$time, "steady.state")) {
+    if (is.null(output$ntp)) {
+      ntp <- 100
+    }
+    else {
+      ntp <- output$ntp
+    }
+    if (is.null(output$ngc)) {
+      ngc <- 5
+    }
+    else {
+      ngc <- output$ngc
+    }
+    if (is.null(output$tol)) {
+      tol <- 0.01
+    }
+    else {
+      tol <- output$tol
+    }
+    if (is.null(group)) 
       group <- list(NULL)
-    
-    if (!is.null(names(group)))  
-      group <- list(group) 
+    if (!is.null(names(group))) 
+      group <- list(group)
     G <- length(group)
-    
-    if (!is.null(treatment)){
-      for (g in (1:G))
-        group[[g]]$treatment <- treatment
+    if (!is.null(treatment)) {
+      for (g in (1:G)) group[[g]]$treatment <- treatment
       treatment <- NULL
     }
-    for (g in (1:G)){
-      if (!is.null(names(group[[g]]$treatment)))  
-        group[[g]]$treatment <- list(group[[g]]$treatment) 
-    } 
-    
-    # ppcm
-    pmtau=1
+    for (g in (1:G)) {
+      if (!is.null(names(group[[g]]$treatment))) 
+        group[[g]]$treatment <- list(group[[g]]$treatment)
+    }
+    pmtau = 1
     tfd <- Inf
-    
-    for (g in (1:G)){
-      for (k in seq(1,length(group[[g]]$treatment))){
+    for (g in (1:G)) {
+      for (k in seq(1, length(group[[g]]$treatment))) {
         trtk <- group[[g]]$treatment[[k]]
-        if (is.null(trtk$ii))
-          stop("inter dose interval (ii) should be an element of treatment when exposure at steady state is computed", call.=FALSE)
-        pmtau <- ppcm(pmtau,trtk$ii) 
-        if(!any("tfd" %in% names(trtk)))
+        if (is.null(trtk$ii)) 
+          stop("inter dose interval (ii) should be an element of treatment when exposure at steady state is computed", 
+               call. = FALSE)
+        pmtau <- ppcm(pmtau, trtk$ii)
+        if (!any("tfd" %in% names(trtk))) 
           group[[g]]$treatment[[k]]$tfd <- 0
         tfd <- min(tfd, group[[g]]$treatment[[k]]$tfd)
       }
     }
-    #--------------------------------
     mgc <- 2
-    T <- ngc*pmtau
+    T <- ngc * pmtau
     gr1 <- group
-    for (g in (1:G)){
+    for (g in (1:G)) {
       trtg <- group[[g]]$treatment
       trt1 <- trtg
-      for (k in seq(1,length(trtg))){
+      for (k in seq(1, length(trtg))) {
         trtk <- trtg[[k]]
-        trtk$time <- seq(trtk$tfd,T+trtk$tfd,by=trtk$ii)   
+        trtk$time <- seq(trtk$tfd, T + trtk$tfd, by = trtk$ii)
         trtk$ii <- NULL
         trtk$tfd <- NULL
         trt1[[k]] <- trtk
       }
       gr1[[g]]$treatment <- trt1
     }
-    out1 <- list(name=output$name, time=seq(tfd,T+tfd-pmtau/mgc,by=pmtau/mgc))
-    if (length(gr1)==1){
+    out1 <- list(name = output$name, time = seq(tfd, T + 
+                                                  tfd - pmtau/mgc, by = pmtau/mgc))
+    if (length(gr1) == 1) {
       trt1 <- gr1[[1]]$treatment
       gr1[[1]]$treatment <- NULL
-      if (length(gr1[[1]])==0)
+      if (length(gr1[[1]]) == 0) 
         gr1 <- NULL
-    }else{
+    }
+    else {
       trt1 <- NULL
-    }   
-    r1 <- simulx(model=model,group=gr1,treatment=trt1, parameter=parameter,
-                 output=out1,settings=settings,varlevel=varlevel)
+    }
+    r1 <- simulx(model = model, group = gr1, treatment = trt1, 
+                 parameter = parameter, output = out1, settings = settings, 
+                 varlevel = varlevel)
     r1$treatment <- NULL
     r.names <- names(r1)
     alpha <- Inf
-    for (k in seq(1:length(r1))){
+    for (k in seq(1:length(r1))) {
       namek <- r.names[k]
       rk <- r1[[k]]
-      if (any("time" %in% names(rk))){
+      if (any("time" %in% names(rk))) {
         i.id <- any("id" %in% names(rk))
-        if (!i.id) {rk$id <- factor(1)}
+        if (!i.id) {
+          rk$id <- factor(1)
+        }
         N <- nlevels(rk$id)
         i2 <- 0
-        for (i in (1:N)){
-          i1 <- i2 + 1 
-          i2 <- i2 + ngc*mgc
-          rki <- rk[i1:i2,]
-          fki <- matrix(rki[namek][[1]],ncol=ngc)
-          dki <- diff(apply(fki,2,mean))
+        for (i in (1:N)) {
+          i1 <- i2 + 1
+          i2 <- i2 + ngc * mgc
+          rki <- rk[i1:i2, ]
+          fki <- matrix(rki[namek][[1]], ncol = ngc)
+          dki <- diff(apply(fki, 2, mean))
           alphai <- diff(log(abs(dki)))
-          if (max(alphai) <0){
-            alpha <- min(alpha,-tail(alphai,n=1))
-          }else if (min(alphai)>0){
-            stop("\n\nSorry... exposure was not able to estimate the rate of convergence to steady state...
-Try increasing ngc, or fix the number of doses", call.=FALSE)
+          if (max(alphai) < 0) {
+            alpha <- min(alpha, -tail(alphai, n = 1))
+          }
+          else if (min(alphai) > 0) {
+            stop("\n\nSorry... exposure was not able to estimate the rate of convergence to steady state...\nTry increasing ngc, or fix the number of doses", 
+                 call. = FALSE)
           }
         }
       }
     }
-    M <- ceiling(-log(tol)/alpha)+1
-    #----------------------------------
-    
-    T <- M*pmtau + tfd
-    for (g in (1:G)){
+    M <- ceiling(-log(tol)/alpha) + 1
+    T <- M * pmtau + tfd
+    for (g in (1:G)) {
       trtg <- group[[g]]$treatment
-      for (k in seq(1,length(trtg))){
+      for (k in seq(1, length(trtg))) {
         trtk <- trtg[[k]]
-        trtk$time <- seq(trtk$tfd,T+trtk$tfd,by=trtk$ii)   
+        trtk$time <- seq(trtk$tfd, T + trtk$tfd, by = trtk$ii)
         trtk$ii <- NULL
         trtk$tfd <- NULL
         trtg[[k]] <- trtk
       }
       group[[g]]$treatment <- trtg
     }
-    output <- list(name=output$name, time=seq(T-pmtau,T,length=ntp))
-    if (length(group)==1){
+    output <- list(name = output$name, time = seq(T - pmtau, 
+                                                  T, length = ntp))
+    if (length(group) == 1) {
       treatment <- group[[1]]$treatment
       group[[1]]$treatment <- NULL
-      if (length(group[[1]])==0)
+      if (length(group[[1]]) == 0) 
         group <- NULL
     }
   }
-  if (is.null(output$time))
-    stop("'output' should be a list with 'time' as an element", call.=FALSE)
+  if (is.null(output$time)) 
+    stop("'output' should be a list with 'time' as an element", 
+         call. = FALSE)
   t <- output$time
   t.min <- min(t)
   t.max <- max(t)
-  t.n   <- length(t)
-  if (sd(diff(t))<mean(diff(t))*0.001) {
+  t.n <- length(t)
+  if (sd(diff(t)) < mean(diff(t)) * 0.001) {
     cst.step <- T
-    t.step <- (t.max - t.min)/(t.n-1)
-    output$time <- seq(t.min,t.max, by=t.step)
-  } else {
+    t.step <- (t.max - t.min)/(t.n - 1)
+    output$time <- seq(t.min, t.max, by = t.step)
+  }
+  else {
     cst.step <- F
     t.step <- NA
     dt <- diff(t)
   }
-  r.simul <- simulx(model=model,group=group,treatment=treatment,parameter=parameter,
-                    output=output,data=data,project=project,settings=settings,
-                    regressor=regressor,varlevel=varlevel)
+  r.simul <- simulx(model = model, group = group, treatment = treatment, 
+                    parameter = parameter, output = output, data = data, 
+                    project = project, settings = settings, regressor = regressor, 
+                    varlevel = varlevel)
   r.simul$treatment <- NULL
   r.names <- names(r.simul)
   res <- list()
   kk <- 0
-  for (k in seq(1:length(r.simul))){
+  for (k in seq(1:length(r.simul))) {
     namek <- r.names[k]
     rk <- r.simul[[k]]
-    if (any("time" %in% names(rk))){
-      kk <- kk+1
+    if (any("time" %in% names(rk))) {
+      kk <- kk + 1
       i.id <- any("id" %in% names(rk))
       i.group <- any("group" %in% names(rk))
-      if (!i.id)
+      if (!i.id) 
         rk$id <- as.factor(1)
       N <- nlevels(rk$id)
-      cmin <- vector(length=N)
-      tmin <- vector(length=N)
-      cmax <- vector(length=N)
-      tmax <- vector(length=N)
-      auc  <- vector(length=N)
-      gr   <- vector(length=N)
+      cmin <- vector(length = N)
+      tmin <- vector(length = N)
+      cmax <- vector(length = N)
+      tmax <- vector(length = N)
+      auc <- vector(length = N)
+      gr <- vector(length = N)
       i2 <- 0
-      for (i in (1:N)){
-        t.ni <- sum(rk$id==levels(rk$id)[i])
-        i1 <- i2 + 1 
+      for (i in (1:N)) {
+        t.ni <- sum(rk$id == levels(rk$id)[i])
+        i1 <- i2 + 1
         i2 <- i2 + t.ni
-        rki <- rk[i1:i2,]
+        rki <- rk[i1:i2, ]
         tki <- rki["time"][[1]]
         fki <- rki[namek][[1]]
-        imin <- which.min(fki)
-        tmin[i] <- tki[imin]
-        cmin[i] <- fki[imin]
-        imax <- which.max(fki)
-        tmax[i] <- tki[imax]
-        cmax[i] <- fki[imax]
-        if (cst.step)
-          auc[i] <- ((fki[1]+fki[t.ni])/2+sum(fki[2:(t.ni-1)]))*t.step
-        else
-          auc[i] <- sum(dt*(fki[1:(t.ni-1)]+fki[2:t.ni]))/2
-        if (i.group){ gr[i] <- rki$group[1]  }
+        if(is.na(fki[1])){
+          imin <- NA
+          tmin[i] <- NA
+          cmin[i] <- NA
+          imax <- NA
+          tmax[i] <- NA
+          cmax[i] <- NA
+          auc[i]<- NA
+        }else{
+          imin <- which.min(fki)
+          tmin[i] <- tki[imin]
+          cmin[i] <- fki[imin]
+          imax <- which.max(fki)
+          tmax[i] <- tki[imax]
+          cmax[i] <- fki[imax]
+          if (cst.step) 
+            auc[i] <- ((fki[1] + fki[t.ni])/2 + sum(fki[2:(t.ni - 
+                                                             1)])) * t.step
+          else auc[i] <- sum(dt * (fki[1:(t.ni - 1)] + 
+                                     fki[2:t.ni]))/2
+        }
+        if (i.group) {
+          gr[i] <- rki$group[1]
+        }
       }
-      if (!i.id){
-        res[[kk]] <- data.frame(t1=t.min, t2=t.max, step=t.step, auc, 
+      if (!i.id) {
+        res[[kk]] <- data.frame(t1 = t.min, t2 = t.max, 
+                                step = t.step, auc, tmax, cmax, tmin, cmin)
+      }
+      else if (!i.group) {
+        res[[kk]] <- data.frame(id = factor(1:N), t1 = t.min, 
+                                t2 = t.max, step = t.step, auc, tmax, cmax, 
+                                tmin, cmin)
+      }
+      else {
+        res[[kk]] <- data.frame(id = factor(1:N), group = as.factor(gr), 
+                                t1 = t.min, t2 = t.max, step = t.step, auc, 
                                 tmax, cmax, tmin, cmin)
-      }else if (!i.group){
-        res[[kk]] <- data.frame(id=factor(1:N), t1=t.min, t2=t.max, step=t.step, auc, 
-                                tmax, cmax, tmin, cmin)
-      }else{
-        res[[kk]] <- data.frame(id=factor(1:N), group=as.factor(gr), t1=t.min, t2=t.max, step=t.step, auc, 
-                                tmax, cmax, tmin, cmin)        
       }
       names(res)[kk] <- namek
     }
